package at.xaxa.ledger.data

import at.xaxa.ledger.data.db.Entry.EntryEntity
import at.xaxa.ledger.data.db.LedgerDao
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map


class EntryRepository(private val ledgerDao: LedgerDao){


    fun getAllEntries(): Flow<List<Entry>> {
        return ledgerDao.getAllEntries().map {
            it.map {entry -> Entry(entry._id, entry.name, entry.amount, entry.date, entry.categoryName) }
        }
    }

    suspend fun findEntryById(id: Int): Entry {
        val entry = ledgerDao.findEntryById(id)
        return Entry(
            entry._id, entry.name, entry.amount, entry.date, entry.categoryName
        )
    }
    suspend fun insertEntry(entry: Entry) {
        ledgerDao.addEntry(EntryEntity(_id=0, entry.name, entry.amount, entry.date, entry.categoryName))
    }

    suspend fun updateEntry(entry: Entry) {
        ledgerDao.updateEntry(EntryEntity(entry.id, entry.name, entry.amount, entry.date, entry.categoryName))
    }
    suspend fun deleteEntry(entry: Entry) {
        ledgerDao.deleteEntry(EntryEntity(_id = entry.id, entry.name, entry.amount, entry.date, entry.categoryName))
    }

}