package at.xaxa.ledger.data.db

import androidx.room.Dao
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Transaction
import androidx.room.Update
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.data.db.Entry.EntryEntity
import kotlinx.coroutines.flow.Flow

@Dao
interface LedgerDao {
    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun addCategory(categoryEntity: CategoryEntity)

    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun addEntry(entryEntity: EntryEntity)

    @Transaction
    @Query("SELECT * FROM _transaction WHERE categoryName = :categoryName")
    suspend fun getEntryWithCategoryName(categoryName: String): List<EntryCategoryRelation>

    @Update
    suspend fun updateCategory(categoryEntity: CategoryEntity)

    @Update
    suspend fun updateEntry(entryEntity: EntryEntity)


    @Delete
    suspend fun deleteCategory(categoryEntity: CategoryEntity)


    @Delete
    suspend fun deleteEntry(entryEntity: EntryEntity)


    @Query("SELECT * FROM category WHERE _id = :id")
    suspend fun findCategoryById(id: Int) : CategoryEntity


    @Query("SELECT * FROM category")
    fun getAllCategory(): Flow<List<CategoryEntity>>


    @Query("SELECT * FROM _transaction WHERE _id = :id")
    suspend fun findEntryById(id: Int) : EntryEntity


    @Query("SELECT * FROM _transaction")
    fun getAllEntries(): Flow<List<EntryEntity>>

}
